#
# spec file for package php5-pear-Date
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           php5-pear-Date
%define pear_name  Date
%define pear_sname date
Summary:        Generic date/time handling
License:        BSD-3-Clause
Group:          Productivity/Networking/Web/Servers
Version:        1.5.0a4
Release:        4.1
BuildArch:      noarch
Url:            http://pear.php.net/package/%{pear_name}
Source:         %{pear_name}-%{version}.tgz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  php >= 4.3
%if 0%{?sles_version} == 11
BuildRequires:  php53-devel
%else
BuildRequires:  php-macros
%endif
BuildRequires:  php-pear
Requires:       php >= 4.3
Requires:       php-pear
Provides:       pear-%{pear_name}
Provides:       php-pear-%{pear_name}
# Fix for renaming (package convention)
Provides:       pear-%{pear_sname} = %{version}
Provides:       php-pear-%{pear_sname} = %{version}
Provides:       php5-pear-%{pear_sname} = %{version}
Obsoletes:      pear-%{pear_sname} < %{version}
Obsoletes:      php-pear-%{pear_sname} < %{version}
Obsoletes:      php5-pear-%{pear_sname} < %{version}

%description
Generic classes for representation and manipulation of
dates, times and time zones without the need of timestamps,
which is a huge limitation for php programs. Includes time zone data,
time zone conversions and many date/time conversions.
It does not rely on 32-bit system date stamps, so
you can display calendars and compare dates that date
pre 1970 and post 2038. This package also provides a class
to convert date strings between Gregorian and Human calendar formats.

%prep
%setup -c

%build

%install
%{__mv} package*.xml %{pear_name}-%{version}
cd %{pear_name}-%{version}
PHP_PEAR_PHP_BIN="$(which php) -d memory_limit=50m"
%{__pear} -v \
	-d doc_dir=/doc \
	-d bin_dir=%{_bindir} \
	-d data_dir=%{peardir}/data \
	install --offline --nodeps -R "$RPM_BUILD_ROOT" package.xml

%{__install} -D -m 0644 package.xml $RPM_BUILD_ROOT%{php_pearxmldir}/%{pear_name}.xml

%{__rm} -rf $RPM_BUILD_ROOT/{doc,tmp}
%{__rm} -rf $RPM_BUILD_ROOT/%{php_peardir}/.{filemap,lock,registry,channels,depdb,depdblock}

# This should actually be performed in the build sections.  But if that
# is done the pear installer fails, because the md5sum of the files are not
# as expected.
# rpmlint: wrong-file-end-of-line-encoding
# FIXME: replace perl 'oneliner' with some other: php or sed
%{__perl} -p -i -e 's|\r\n|\n|' docs/TODO

cd ..

%php_pear_gen_filelist

%post  
# on `rpm -ivh` PARAM is 1
# on `rpm -Uvh` PARAM is 2
if [ "$1" = "1" ]; then
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml
fi
if [ "$1" = "2" ]; then
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml 
fi

%postun  
# on `rpm -e` PARAM is 0
if [ "$1" = "0" ]; then
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name}
fi 

%clean
%{__rm} -rf %{buildroot}

%files -f %{name}.files
%defattr(-, root, root)
%doc %{pear_name}-%{version}/docs/*

%changelog
* Mon Jan 19 2015 lang@b1-systems.de
- version 1.5.0a4 fixed tarball (re-issue of 1.5.0a4)
  QA release
  Request #17626 Patch to add missing longname and dstlongname info
  Bug #19184 use date_default_timezone_get() instead of ini_get(date.timezone)
  Bug #19568 setDate() handles ISO week dates incorrectly
* Tue Nov 27 2012 Ralf Lang <lang@b1-systems.de>
- reverting back to 1.5.0a2 because a3 had a corrupt upstream tarball
* Tue Nov 27 2012 Ralf Lang <lang@b1-systems.de>
- version 1.5.0a3
- Request #17626 Patch to add missing longname and dstlongname info
- Bug #19184 use date_default_timezone_get() instead of ini_get(date.timezone)
- Bug #19568 setDate() handles ISO week dates incorrectly
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Thu Jan 20 2011 chris@computersalat.de
- change to php_pear_gen_filelist macro
* Wed Jan 19 2011 chris@computersalat.de
- pkg rename php5-pear-Date
- merge with php-pear-date, php5-pear-date
- changelog to changes file
- added php-macros
* Thu May 21 2009 chris@computersalat.de
- added stuff to automatically create correct filelist
  o tested against Factory (1120)
  o opensuse >= 1100 complains about
    "directory not owned by package"
- some rpmlint stuff
* Tue May 19 2009 chris@computersalat.de
- new version 1.4.7
- beautify spec
  o new spec header
  o package rename due to package convention
  o removed php4 stuff, deps
  o added Provides and Obsoletes for old package names.
    This should not break deps
* Sat Jun 17 2006 suse-tux@gmx.de
- made spec file portable for older/new suse-versions
- removed #usedforbuild, added %%clean-macro
- added rpmmacros (changed "sed" to "%%__sed" etc.)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 mmarek@suse.de
- fix filelist, remove temporary files created by pear installer
- unify php5-pear-*.spec files
- increase php's memory_limit during installation (parsing
  xml needs more than default 8M sometimes)
* Mon Jan 16 2006 mmarek@suse.cz
- created package to satisfy horde dependencies
